# sixties

Parsing of fixed width text databases derived in the Seventies from the Sixties' spirit of the previous century.

[License: MIT](https://git.sr.ht/~sthagen/sixties/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/sixties.svg?style=flat)](https://pypi.python.org/pypi/sixties/)
[![downloads](https://pepy.tech/badge/sixties/month)](https://pepy.tech/project/sixties)
[![wheel](https://img.shields.io/pypi/wheel/sixties.svg?style=flat)](https://pypi.python.org/pypi/sixties/)
[![supported-versions](https://img.shields.io/pypi/pyversions/sixties.svg?style=flat)](https://pypi.python.org/pypi/sixties/)
[![supported-implementations](https://img.shields.io/pypi/implementation/sixties.svg?style=flat)](https://pypi.python.org/pypi/sixties/)

## Documentation

User and developer [documentation of sixties](https://codes.dilettant.life/docs/sixties).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of sixties](https://todo.sr.ht/~sthagen/sixties).

## Primary Source repository

The primary source repository of [sixties is at sourcehut](https://git.sr.ht/~sthagen/sixties)
a collection of tools useful for software development.

## What is in it

Probably nothing of interest for most visitors.

## Status

Experimental

**Note**: The default branch is `default`.
